@@ -29,7 +29,7 @@ if (require("hdf5r")) {
     m <- Matrix::Matrix(matrix(c(1:10)), sparse = FALSE)
     expect_false(is_sparse(m))
     expect_true(is_sparse(methods::as(m, "CsparseMatrix")))
-    expect_false(is_sparse(methods::as(m, "dgeMatrix")))
+    expect_false(is_sparse(methods::as(m, "denseMatrix")))
   })
 
 
